#!/usr/bin/env node
/*!
 * gitmars v7.0.0-beta.22
 * 这是一个git工作流工具
 * (c) 2021-2024 saqqdy<https://github.com/saqqdy> 
 * Released under the MIT License.
 */
import { program } from 'commander';
import sh from 'shelljs';
import chalk from 'chalk';
import to from 'await-to-done';
import { confirm } from '@inquirer/prompts';
import { getGitRevParse, getIsGitProject } from '@gitmars/git';
import { cleanPkgInfo, cleanCache } from '@gitmars/cache';
import { createArgs, removeFile } from '@gitmars/utils';
import { cleanBuildConfig } from '@gitmars/build';
import lang from './common/local.mjs';
import { cmdConfig } from './conf/clean.mjs';

sh.config.silent = true;
const { t } = lang;
const { green, yellow } = chalk;
const { args, options } = cmdConfig;
const { gitDir } = getGitRevParse();
program.name("gitm clean").usage("[-f --force]").description(t("Clean gitmars cache"));
if (args.length > 0)
  program.arguments(createArgs(args));
options.forEach((o) => {
  program.option(o.flags, o.description, o.defaultValue);
});
program.action(async (opt) => {
  if (getIsGitProject()) {
    if (opt.force) {
      const [, answer] = await to(
        confirm({
          message: t(
            "You have entered --force, which will also clear the gitmars execution cache. Should I continue?"
          ),
          default: false
        })
      );
      if (!answer) {
        sh.echo(green(t("exited")));
        process.exit(0);
      }
      removeFile([
        {
          name: t("gitmars command queue cache file"),
          url: gitDir + "/.gitmarscommands"
        },
        {
          name: t("gitmars execution log file"),
          url: gitDir + "/.gitmarslog"
        }
      ]);
    }
  } else {
    sh.echo(yellow(t("The current directory is not a git project directory")));
  }
  cleanBuildConfig();
  cleanPkgInfo();
  cleanCache();
});
program.parse(process.argv);
