#!/usr/bin/env node
/*!
 * gitmars v7.0.0-beta.22
 * 这是一个git工作流工具
 * (c) 2021-2024 saqqdy<https://github.com/saqqdy> 
 * Released under the MIT License.
 */
import { program } from 'commander';
import columnify from 'columnify';
import chalk from 'chalk';
import { getIsGitProject, getCurrentBranch, getGitStatus } from '@gitmars/git';
import { echo, createArgs } from '@gitmars/utils';
import lang from './common/local.mjs';
import { cmdConfig } from './conf/status.mjs';

const { t } = lang;
const { cyan, green, red, yellow } = chalk;
const { args, options } = cmdConfig;
if (!getIsGitProject()) {
  echo(red(t("The current directory is not a git project directory")));
  process.exit(1);
}
program.name("gitm status").usage("[-k --keep [keep]]").description(t("Restore staging area file"));
if (args.length > 0)
  program.arguments(createArgs(args));
options.forEach((o) => {
  program.option(o.flags, o.description, o.defaultValue);
});
program.action(() => {
  const current = getCurrentBranch();
  const status = getGitStatus();
  const data = [];
  let num = Math.max(
    status["??"].length,
    status.A.length,
    status.M.length,
    status.D.length,
    status.UU.length
  );
  while (num--) {
    data.unshift({
      added: yellow(status.A[num] || ""),
      modified: green(status.M[num] || ""),
      deleted: red(status.D[num] || ""),
      unmerged: red(status.UU),
      untracked: cyan(status["??"][num] || "")
    });
  }
  echo(green(t("Current branch: {something}", { something: current }) + "\n"));
  echo(columnify(data));
});
program.parse(process.argv);
